@@ -1,4 +1,4 @@
-# Copyright 2009 10gen, Inc.
+# Copyright 2009-2010 10gen, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,7 +14,16 @@
 
 """Exceptions raised by the :mod:`gridfs` package"""
 
-class CorruptGridFile(Exception):
+from pymongo.errors import PyMongoError
+
+
+class GridFSError(PyMongoError):
+    """Base class for all GridFS exceptions.
+
+    .. versionadded:: 1.5
+    """
+
+class CorruptGridFile(GridFSError):
     """Raised when a :class:`~gridfs.grid_file.GridFile` instance is
     malformed.
     """
