@@ -420,8 +420,8 @@ class Connection(object): # TODO support auth for pooling
     def __find_master(self):
         """Create a new socket and use it to figure out who the master is.
 
-        Sets __host and __port so that :attr:`host` and :attr:`port` will return the
-        address of the master.
+        Sets __host and __port so that :attr:`host` and :attr:`port`
+        will return the address of the master.
         """
         self.__host = None
         self.__port = None
@@ -435,25 +435,19 @@ class Connection(object): # TODO support auth for pooling
                     sock.connect((host, port))
                     sock.settimeout(self.__network_timeout)
                     master = self.__master(sock)
-                    if master is True:
+                    if master is True or self.__slave_okay:
                         self.__host = host
                         self.__port = port
                         return
                     if not master:
-                        if self.__slave_okay:
-                            self.__host = host
-                            self.__port = port
-                            return
-
                         raise ConfigurationError("trying to connect directly to"
                                                  " slave %s:%r - must specify "
                                                  "slave_okay to connect to "
                                                  "slaves" % (host, port))
                     if master not in self.__nodes:
-                        raise ConfigurationError(
-                            "%r claims master is %r, "
-                            "but that's not configured" %
-                            ((host, port), master))
+                        raise ConfigurationError("%r claims master is %r, "
+                                                 "but that's not configured" %
+                                                 ((host, port), master))
                 except socket.error, e:
                     continue
             finally:
@@ -798,6 +792,9 @@ class Connection(object): # TODO support auth for pooling
           - `username` (optional): username for source database
           - `password` (optional): password for source database
 
+        .. note:: Specifying `username` and `password` requires server
+           version **>= 1.3.3+**.
+
         .. versionadded:: 1.5
         """
         if not isinstance(from_name, basestring):
