@@ -1,4 +1,4 @@
-# Copyright 2009 10gen, Inc.
+# Copyright 2009-2010 10gen, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,8 +19,8 @@ instances."""
 
 import random
 
-from database import Database
-from connection import Connection
+from pymongo.connection import Connection
+from pymongo.database import Database
 
 
 class MasterSlaveConnection(object):
@@ -58,21 +58,21 @@ class MasterSlaveConnection(object):
         self.__master = master
         self.__slaves = slaves
 
+    @property
     def master(self):
         return self.__master
-    master = property(master)
 
+    @property
     def slaves(self):
         return self.__slaves
-    slaves = property(slaves)
 
+    @property
     def slave_okay(self):
         """Is it okay for this connection to connect directly to a slave?
 
         This is always True for MasterSlaveConnection instances.
         """
         return True
-    slave_okay = property(slave_okay)
 
     def set_cursor_manager(self, manager_class):
         """Set the cursor manager for this connection.
