@@ -1,4 +1,4 @@
-# Copyright 2009 10gen, Inc.
+# Copyright 2009-2010 10gen, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,24 +14,32 @@
 
 """Test the database module."""
 
-import unittest
-import random
 import datetime
+import random
 import sys
 sys.path[0:0] = [""]
+import unittest
 
-from pymongo.errors import InvalidName, InvalidOperation
-from pymongo.errors import CollectionInvalid, OperationFailure
-from pymongo.son import SON
-from pymongo.objectid import ObjectId
-from pymongo.database import Database
-from pymongo import ASCENDING, DESCENDING, OFF, SLOW_ONLY, ALL
-from pymongo.connection import Connection
-from pymongo.collection import Collection
-from pymongo.dbref import DBRef
+from pymongo import (ALL,
+                     ASCENDING,
+                     DESCENDING,
+                     helpers,
+                     OFF,
+                     SLOW_ONLY)
 from pymongo.code import Code
+from pymongo.collection import Collection
+from pymongo.connection import Connection
+from pymongo.database import Database
+from pymongo.dbref import DBRef
+from pymongo.errors import (CollectionInvalid,
+                            InvalidName,
+                            InvalidOperation,
+                            OperationFailure)
+from pymongo.objectid import ObjectId
+from pymongo.son import SON
 from pymongo.son_manipulator import AutoReference, NamespaceInjector
-from test_connection import get_connection
+from test import version
+from test.test_connection import get_connection
 
 
 class TestDatabase(unittest.TestCase):
@@ -72,7 +80,6 @@ class TestDatabase(unittest.TestCase):
         self.assertRaises(TypeError, db.create_collection, 5)
         self.assertRaises(TypeError, db.create_collection, None)
         self.assertRaises(InvalidName, db.create_collection, "coll..ection")
-        self.assertRaises(TypeError, db.create_collection, "test", 5)
 
         test = db.create_collection("test")
         test.save({"hello": u"world"})
@@ -201,6 +208,11 @@ class TestDatabase(unittest.TestCase):
         self.assertEqual(None, db.error())
         self.assertEqual(None, db.previous_error())
 
+    def test_command(self):
+        db = self.connection.admin
+
+        self.assertEqual(db.command("buildinfo"), db.command({"buildinfo": 1}))
+
     def test_last_status(self):
         db = self.connection.pymongo_test
 
@@ -214,19 +226,17 @@ class TestDatabase(unittest.TestCase):
         self.failIf(db.last_status()["updatedExisting"])
 
     def test_password_digest(self):
-        db = self.connection.pymongo_test
+        self.assertRaises(TypeError, helpers._password_digest, 5)
+        self.assertRaises(TypeError, helpers._password_digest, True)
+        self.assertRaises(TypeError, helpers._password_digest, None)
 
-        self.assertRaises(TypeError, db._password_digest, 5)
-        self.assertRaises(TypeError, db._password_digest, True)
-        self.assertRaises(TypeError, db._password_digest, None)
-
-        self.assert_(isinstance(db._password_digest("mike", "password"),
+        self.assert_(isinstance(helpers._password_digest("mike", "password"),
                                 unicode))
-        self.assertEqual(db._password_digest("mike", "password"),
+        self.assertEqual(helpers._password_digest("mike", "password"),
                          u"cd7e45b3b2767dc2fa9b6b548457ed00")
-        self.assertEqual(db._password_digest("mike", "password"),
-                         db._password_digest(u"mike", u"password"))
-        self.assertEqual(db._password_digest("Gustave", u"Dor\xe9"),
+        self.assertEqual(helpers._password_digest("mike", "password"),
+                         helpers._password_digest(u"mike", u"password"))
+        self.assertEqual(helpers._password_digest("Gustave", u"Dor\xe9"),
                          u"81e0e2364499209f466e75926a162d73")
 
     def test_authenticate_add_remove_user(self):
@@ -458,5 +468,29 @@ class TestDatabase(unittest.TestCase):
         self.assertEqual("buzz", db.users.find_one()["messages"][0]["title"])
         self.assertEqual("bar", db.users.find_one()["messages"][1]["title"])
 
+    def test_system_js(self):
+        db = self.connection.pymongo_test
+        db.system.js.remove()
+
+        self.assertEqual(0, db.system.js.count())
+        db.system_js.add = "function(a, b) { return a + b; }"
+        self.assertEqual(1, db.system.js.count())
+        self.assertEqual(6, db.system_js.add(1, 5))
+
+        del db.system_js.add
+        self.assertEqual(0, db.system.js.count())
+        if version.at_least(db.connection, (1, 3, 2, -1)):
+            self.assertRaises(OperationFailure, db.system_js.add, 1, 5)
+
+        # TODO right now CodeWScope doesn't work w/ system js
+        # db.system_js.scope = Code("return hello;", {"hello": 8})
+        # self.assertEqual(8, db.system_js.scope())
+
+        self.assertRaises(OperationFailure, db.system_js.non_existant)
+
+        db.system_js.no_param = Code("return 5;")
+        self.assertEqual(5, db.system_js.no_param())
+
+
 if __name__ == "__main__":
     unittest.main()
